package com.yanzhu.manage.service;

import java.util.List;
import com.yanzhu.manage.domain.ProProjectInfoSubdepts;

/**
 * 分包单位Service接口
 * 
 * @author JiangYuQi
 * @date 2024-08-25
 */
public interface IProProjectInfoSubdeptsService 
{
    /**
     * 查询分包单位
     * 
     * @param id 分包单位主键
     * @return 分包单位
     */
    public ProProjectInfoSubdepts selectProProjectInfoSubdeptsById(Long id);

    /**
     * 查询分包单位列表
     * 
     * @param proProjectInfoSubdepts 分包单位
     * @return 分包单位集合
     */
    public List<ProProjectInfoSubdepts> selectProProjectInfoSubdeptsList(ProProjectInfoSubdepts proProjectInfoSubdepts);

    /**
     * 新增分包单位
     * 
     * @param proProjectInfoSubdepts 分包单位
     * @return 结果
     */
    public int insertProProjectInfoSubdepts(ProProjectInfoSubdepts proProjectInfoSubdepts);

    /**
     * 修改分包单位
     * 
     * @param proProjectInfoSubdepts 分包单位
     * @return 结果
     */
    public int updateProProjectInfoSubdepts(ProProjectInfoSubdepts proProjectInfoSubdepts);

    /**
     * 修改分包单位
     *
     * @param proProjectInfoSubdepts 分包单位
     * @return 结果
     */
    public int updateProProjectInfoSubdeptsEntity(ProProjectInfoSubdepts proProjectInfoSubdepts);

    /**
     * 批量删除分包单位
     * 
     * @param ids 需要删除的分包单位主键集合
     * @return 结果
     */
    public int deleteProProjectInfoSubdeptsByIds(Long[] ids);

    /**
     * 删除分包单位信息
     * 
     * @param id 分包单位主键
     * @return 结果
     */
    public int deleteProProjectInfoSubdeptsById(Long id);
}
